@@ -18,7 +18,6 @@
  */
 package org.mvndaemon.mvnd.client;
 
-import java.io.File;
 import java.io.IOException;
 import java.net.InetSocketAddress;
 import java.net.SocketAddress;
@@ -52,13 +51,13 @@ import org.mvndaemon.mvnd.common.DaemonRegistry;
 import org.mvndaemon.mvnd.common.DaemonState;
 import org.mvndaemon.mvnd.common.DaemonStopEvent;
 import org.mvndaemon.mvnd.common.Environment;
-import org.mvndaemon.mvnd.common.MavenDaemon;
 import org.mvndaemon.mvnd.common.Message;
 import org.mvndaemon.mvnd.common.Os;
 import org.mvndaemon.mvnd.common.SocketFamily;
 import org.mvndaemon.mvnd.common.logging.ClientOutput;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import org.slf4j.impl.SimpleLogger;
 
 import static java.lang.Thread.sleep;
 import static org.mvndaemon.mvnd.common.DaemonState.Canceled;
@@ -144,6 +143,8 @@ public class DaemonConnector {
                 parameters.daemonStorage().toString());
         properties.put(
                 Environment.MVND_REGISTRY.getProperty(), parameters.registry().toString());
+        properties.put(
+                Environment.MVND_JAVA_HOME.getProperty(), parameters.javaHome().toString());
         properties.putAll(parameters.getDaemonOptsMap());
         Environment.setProperties(properties);
         AtomicReference<Throwable> throwable = new AtomicReference<>();
@@ -339,32 +340,44 @@ public class DaemonConnector {
         final Path mvndHome = parameters.mvndHome();
         final Path workingDir = parameters.userDir();
         String command = "";
-        try (DirectoryStream<Path> jarPaths = Files.newDirectoryStream(mvndHome.resolve("lib"))) {
+        try {
             List<String> args = new ArrayList<>();
             // executable
             final String java = Os.current().isUnixLike() ? "bin/java" : "bin\\java.exe";
             args.add(parameters.javaHome().resolve(java).toString());
             // classpath
-            String mvndCommonPath = null;
             String mvndAgentPath = null;
-            for (Path jar : jarPaths) {
-                String s = jar.getFileName().toString();
-                if (s.endsWith(".jar")) {
-                    if (s.startsWith("mvnd-common-")) {
-                        mvndCommonPath = jar.toString();
-                    } else if (s.startsWith("mvnd-agent-")) {
-                        mvndAgentPath = jar.toString();
+            String plexusClassworldsPath = null;
+            try (DirectoryStream<Path> jarPaths = Files.newDirectoryStream(
+                    mvndHome.resolve("mvn").resolve("lib").resolve("mvnd"))) {
+                for (Path jar : jarPaths) {
+                    String s = jar.getFileName().toString();
+                    if (s.endsWith(".jar")) {
+                        if (s.startsWith("mvnd-agent-")) {
+                            mvndAgentPath = jar.toString();
+                        }
                     }
                 }
             }
-            if (mvndCommonPath == null) {
-                throw new IllegalStateException("Could not find mvnd-common jar in lib/");
+            try (DirectoryStream<Path> jarPaths =
+                    Files.newDirectoryStream(mvndHome.resolve("mvn").resolve("boot"))) {
+                for (Path jar : jarPaths) {
+                    String s = jar.getFileName().toString();
+                    if (s.endsWith(".jar")) {
+                        if (s.startsWith("plexus-classworlds-")) {
+                            plexusClassworldsPath = jar.toString();
+                        }
+                    }
+                }
             }
             if (mvndAgentPath == null) {
-                throw new IllegalStateException("Could not find mvnd-agent jar in lib/");
+                throw new IllegalStateException("Could not find mvnd-agent jar in mvn/lib/mvnd/");
+            }
+            if (plexusClassworldsPath == null) {
+                throw new IllegalStateException("Could not find plexus-classworlds jar in boot/");
             }
             args.add("-classpath");
-            args.add(mvndCommonPath + File.pathSeparator + mvndAgentPath);
+            args.add(plexusClassworldsPath);
             args.add("-javaagent:" + mvndAgentPath);
             // debug options
             if (parameters.property(Environment.MVND_DEBUG).asBoolean()) {
@@ -394,6 +407,12 @@ public class DaemonConnector {
                 address = host + ":" + iPort;
                 output.accept(Message.buildStatus("Daemon listening for debugger on address: " + address));
                 args.add("-agentlib:jdwp=transport=dt_socket,server=y,suspend=y,address=" + address);
+                if (Environment.MVND_KEEP_ALIVE.getCommandLineOption(args) == null) {
+                    System.setProperty(Environment.MVND_KEEP_ALIVE.getProperty(), "1h");
+                }
+                if (Environment.MVND_CONNECT_TIMEOUT.getCommandLineOption(args) == null) {
+                    System.setProperty(Environment.MVND_CONNECT_TIMEOUT.getProperty(), "1h");
+                }
             }
             // jvm args
             String jvmArgs = parameters.jvmArgs();
@@ -419,13 +438,15 @@ public class DaemonConnector {
             }
 
             Environment.MVND_HOME.addSystemProperty(args, mvndHome.toString());
-            args.add("-Dmaven.home=" + mvndHome);
-            args.add("-Dmaven.conf=" + mvndHome.resolve("conf"));
+            args.add("-Dmaven.home=" + mvndHome.resolve("mvn"));
+            args.add("-Dmaven.conf=" + mvndHome.resolve("mvn").resolve("conf"));
+            args.add("-Dclassworlds.conf=" + mvndHome.resolve("bin").resolve("mvnd-daemon.conf"));
+
+            args.add("-D" + SimpleLogger.LOG_FILE_KEY + "="
+                    + parameters.daemonStorage().resolve("daemon-" + daemonId + ".log"));
 
             Environment.MVND_JAVA_HOME.addSystemProperty(
                     args, parameters.javaHome().toString());
-            Environment.LOGBACK_CONFIGURATION_FILE.addSystemProperty(
-                    args, parameters.logbackConfigurationPath().toString());
             Environment.MVND_ID.addSystemProperty(args, daemonId);
             Environment.MVND_DAEMON_STORAGE.addSystemProperty(
                     args, parameters.daemonStorage().toString());
@@ -438,7 +459,7 @@ public class DaemonConnector {
                             .orElseGet(() -> getJavaVersion() >= 16.0f ? SocketFamily.unix : SocketFamily.inet)
                             .toString());
             parameters.discriminatingSystemProperties(args);
-            args.add(MavenDaemon.class.getName());
+            args.add("org.codehaus.plexus.classworlds.launcher.Launcher");
             command = String.join(" ", args);
 
             LOGGER.debug(
@@ -487,7 +508,7 @@ public class DaemonConnector {
             sc.next();
             sc.next();
             String version = sc.next();
-            LOGGER.warn("JAVA VERSION: " + version);
+            LOGGER.warn("JAVA VERSION: {}", version);
             int is = version.charAt(0) == '"' ? 1 : 0;
             int ie = version.indexOf('.', version.indexOf('.', is));
             return Float.parseFloat(version.substring(is, ie));
